@@ -1,5 +1,5 @@
 use {
-    crate::{errors::*, state::*},
+    crate::{errors::ErrorCode, state::*},
     anchor_lang::prelude::*,
     cardinal_token_manager::{
         program::CardinalTokenManager,
@@ -23,20 +23,24 @@ pub struct InvalidateCtx<'info> {
     invalidator: Signer<'info>,
 
     cardinal_token_manager: Program<'info, CardinalTokenManager>,
+    /// CHECK: This is not dangerous because we don't read or write from this account
     token_program: UncheckedAccount<'info>,
 
     // cpi accounts
+    /// CHECK: This is not dangerous because we don't read or write from this account
     #[account(mut)]
     token_manager_token_account: UncheckedAccount<'info>,
+    /// CHECK: This is not dangerous because we don't read or write from this account
     #[account(mut)]
     mint: UncheckedAccount<'info>,
+    /// CHECK: This is not dangerous because we don't read or write from this account
     #[account(mut)]
     recipient_token_account: UncheckedAccount<'info>,
 }
 
 pub fn handler<'key, 'accounts, 'remaining, 'info>(
     ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>,
-) -> ProgramResult {
+) -> Result<()> {
     let token_manager_key = ctx.accounts.token_manager.key();
     let time_invalidator_seeds = &[
         TIME_INVALIDATOR_SEED.as_bytes(),
@@ -52,6 +56,7 @@ pub fn handler<'key, 'accounts, 'remaining, 'info>(
         mint: ctx.accounts.mint.to_account_info(),
         recipient_token_account: ctx.accounts.recipient_token_account.to_account_info(),
         invalidator: ctx.accounts.time_invalidator.to_account_info(),
+        collector: ctx.accounts.invalidator.to_account_info(),
         token_program: ctx.accounts.token_program.to_account_info(),
     };
     let cpi_ctx = CpiContext::new(
