@@ -10,23 +10,23 @@ declare_id!("tmeEDp1RgoDtZFtx6qod3HkbQmv9LMe36uqKVvsLTDE");
 pub mod cardinal_time_invalidator {
     use super::*;
 
-    pub fn init(ctx: Context<InitCtx>, ix: InitIx) -> ProgramResult {
+    pub fn init(ctx: Context<InitCtx>, ix: InitIx) -> Result<()> {
         init::handler(ctx, ix)
     }
 
-    pub fn set_expiration(ctx: Context<SetExpirationCtx>) -> ProgramResult {
+    pub fn set_expiration(ctx: Context<SetExpirationCtx>) -> Result<()> {
         set_expiration::handler(ctx)
     }
 
-    pub fn extend_expiration(ctx: Context<ExtendExpirationCtx>, payment_amount: u64) -> ProgramResult {
+    pub fn extend_expiration(ctx: Context<ExtendExpirationCtx>, payment_amount: u64) -> Result<()> {
         extend_expiration::handler(ctx, payment_amount)
     }
 
-    pub fn invalidate<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> ProgramResult {
+    pub fn invalidate<'key, 'accounts, 'remaining, 'info>(ctx: Context<'key, 'accounts, 'remaining, 'info, InvalidateCtx<'info>>) -> Result<()> {
         invalidate::handler(ctx)
     }
 
-    pub fn close(ctx: Context<CloseCtx>) -> ProgramResult {
+    pub fn close(ctx: Context<CloseCtx>) -> Result<()> {
         close::handler(ctx)
     }
 }
\ No newline at end of file
